Estimates multiplet rate by using barcode matrix dimensions and formulae from the Saijita Lab's calculator (https://satijalab.org/costpercell/)
EstimateMultipletRate(numCellsRecovered, num10xRuns = 1, chemistry = "10xV3")The number of cells recovered (number of columns in the count matrix)
The number of lanes the cells are loaded into (expected to be 1)
The version of 10x chemistry reagent kit used