Create a plot of the library saturation per cell
PlotLibrarySaturation(citeseqCountDir, metricsFile = NULL)The root of the Cite-seq-Count output folder, which should contain umi_count and read_count folders.
If provided, summary metrics will be written to this file.
The overall saturation for this library